;;;; logger.scm - A deride backend to log all activity to files -*- scheme -*-
;;;; Copyright (C) 2001  Neal H Walfield  <neal@cs.uml.edu>
;;;;
;;;; This file is part of Deride
;;;;
;;;; Deride is free software; you can redistribute it and/or modify
;;;; it under the terms of the GNU General Public License as published by
;;;; the Free Software Foundation; either version 2, or (at your option)
;;;; any later version.
;;;; 
;;;; Deride is distributed in the hope that it will be useful,
;;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;;; GNU General Public License for more details.
;;;; 
;;;; You should have received a copy of the GNU General Public License
;;;; along with the Deride; see the file COPYING.  If not, write to
;;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

(define-module (backend logger))

(use-modules (comm irc))
(use-modules (comm hooks))
(use-modules (forum hooks))

;; Communication hook

(add-hook! comm-received-forum-message-hook
	   (lambda (sender forum say msg)
	     (let* ((sep (if say
			     (list "" "")
			     (list "<" ">"))))
	       (display (string-append (car sep) sender forum
				       (cadr sep) " " msg
				       "\n")))))

(add-hook! comm-received-personal-message-hook
	   (lambda (sender say msg)
	     (let ((sep (if say "" "*")))
	     (display (string-append " -> " sep sender sep " "
				     msg "\n")))))

(add-hook! comm-forum-status-message-hook
	   (lambda (forum msg)
	     (display (string-append "[info:" forum "] " msg
				     "\n"))))

(add-hook! comm-global-status-message-hook
	   (lambda (sender msg)
	     (display (string-append "[info:" sender "] " msg
				     "\n"))))

;; Forum hooks

;; Turn LIST, a list of strings into a string with the elements
;; seperated by SEP and the last two elements seperated by FINALSEP.
;; E.g. (list-of-strings->string ("a" "b" "c" "d") ", " " and ")
;;       => "a, b, c and d"
(define (list-of-strings->string list sep finalsep)
  (if (eqv? list '())
      ""
      (string-append
       (if (eqv? (cdr list) '())
	   (car list)
	   (string-append (car list)
			  (if (eqv? (cddr list) '())
			      finalsep
			      sep)
			  (list-of-strings->string (cdr list)
						   sep finalsep))))))

(add-hook! forum-user-joined-hook
	   (lambda (user forum reason)
	     (display (string-append user " joined " forum
				     (if (> (string-length reason) 0)
					 ": " " ")
				     reason "\n"))))

(add-hook! forum-user-parted-hook
	   (lambda (user forum reason)
	     (display (string-append user " has left " forum
				     (if (> (string-length reason) 0)
					 ": " " ")
				     reason "\n"))))

(add-hook! forum-user-quit-hook
	   (lambda (user forum-list reason)
	     (display (string-append
		       user " has quit (was on "
		       (list-of-strings->string forum-list ", " " and ")
		       (if (> (string-length reason) 0) "): " ") ")
		       reason "\n"))))

(add-hook! forum-user-schizophrenia-hook
	   (lambda (old new forum-list reason) 
	     (display (string-append
		       old " has changed his nick to " new
		       " (effects " (list-of-strings->string
				     forum-list ", " " and ")
		       ").\n"))))
