;;;; hooks.scm - Communication hooks -*- scheme -*-
;;;; Copyright (C) 2001  Neal H Walfield  <neal@cs.uml.edu>
;;;;
;;;; This file is part of Deride
;;;;
;;;; Deride is free software; you can redistribute it and/or modify
;;;; it under the terms of the GNU General Public License as published by
;;;; the Free Software Foundation; either version 2, or (at your option)
;;;; any later version.
;;;; 
;;;; Deride is distributed in the hope that it will be useful,
;;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;;; GNU General Public License for more details.
;;;; 
;;;; You should have received a copy of the GNU General Public License
;;;; along with the Deride; see the file COPYING.  If not, write to
;;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

(define-module (comm hooks))

;;; These hooks are called by the communication backends.

;; A message was sent to a forum.
;;
;; Argument 1: The sender of the message.
;;          2: The forum to which the message was directed to.
;;          3: If the sender spoke in the third person, e.g. on irc a `/me ...'
;;          4: The contents of the message.

(define-public comm-received-forum-message-hook (make-hook 4))

;; A message was sent to us (i.e. whispered.  For instance on irc a
;; `/msg user').
;;
;; Argument 1: The sender of the message.
;;          2: If the sender spoke in the third person, e.g. on irc a `/me ...'
;;          3: The contents of the message.

(define-public comm-received-personal-message-hook (make-hook 3))

;; An informational message was sent to a forum.  E.g. a nick or topic
;; change.
;;
;; Argument 1: forum
;;          2: message

(define-public comm-forum-status-message-hook (make-hook 2))

;; A global status message from, e.g. the server.
;;
;; Arguments 1: sender
;;           2: message

(define-public comm-global-status-message-hook (make-hook 2))
